==> haskell-html-conduit-1.3.2.2-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-A6zxohA2iMzCwyaPzwVEb4
key:                  html-conduit-1.3.2.2-A6zxohA2iMzCwyaPzwVEb4
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  426b6fb19e7fa2d26d5b6dc2543e4f0d
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-A6zxohA2iMzCwyaPzwVEb4
depends:
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6.1-HO5zjhEeUfE6auWqLrKi5s
    conduit-extra-1.3.6-8xA72F23Yd029oLw2H0Gnt containers-0.6.5.1
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp text-1.2.5.0
    transformers-0.5.6.2 xml-conduit-1.9.1.4-1z0iYQZlyQrDsnJ3BGJSOM
    xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.2-259-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-Lx4mP1uBEfpZmTwyqw9iF
key:                  html-conduit-1.3.2.2-Lx4mP1uBEfpZmTwyqw9iF
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  4512f2995cdc7079d43a792557abb04c
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-Lx4mP1uBEfpZmTwyqw9iF
depends:
    attoparsec-0.14.4-5wZOVAk6w2AKDrkEEe6wrE base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6.1-Ckc9h7fnWDpBDJPmybS5L6
    conduit-extra-1.3.6-Dfx9C1gdJ9gKYVKsnFnBkS containers-0.6.5.1
    resourcet-1.2.6-8X67eU2dBvUEg6coZ1eeXn text-1.2.5.0
    transformers-0.5.6.2 xml-conduit-1.9.1.4-6Cy4OAqGmHh6kWPzUdeGlJ
    xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
